@@ -5,6 +5,8 @@ import math
 import time
 from typing import TYPE_CHECKING, Any, AsyncGenerator, Dict, List, Tuple, Type, TypeVar
 
+from httpx_sse import aconnect_sse
+from loguru import logger
 from pydantic import BaseModel
 from tqdm import tqdm
 
@@ -108,6 +110,10 @@ class BaseResource:
         response = await self._apost(f"{path}", json=batch_request.model_dump())
         task_id = response.json()
 
+        # No task was started by the backend
+        if task_id is None:
+            return []
+
         # Poll for completion
         start_time = time.time()
         while timeout is None or time.time() - start_time < timeout:
@@ -125,13 +131,47 @@ class BaseResource:
 
         raise TimeoutError(f"Batch operation timed out after {timeout} seconds")
 
+    async def _abatch_create_stream(
+        self,
+        path: str,
+        batch_request: BaseModel,
+        batch_response_type: Type[BatchCreateStatus[TResult]],
+        timeout: float | None = None,
+    ) -> AsyncGenerator[BatchCreateStatus[TResult], None]:
+        """Generic batch create operation that streams status updates.
+
+        Args:
+            path (str): API endpoint path
+            batch_request (BaseModel): Batch request object containing items and options
+            batch_response_type (Type[BatchCreateStatus[TResult]]): Type of the batch response
+            timeout (float | None): Optional timeout in seconds
+
+        Yields:
+            Status objects with updates on batch operation progress
+
+        Raises:
+            TimeoutError: If operation times out
+
+        """
+        # Initiate batch operation
+        response = await self._apost(f"{path}", json=batch_request.model_dump())
+        task_id = response.json()
+
+        # No task was started by the backend
+        if task_id is None:
+            return
+
+        # Stream status updates using the existing _aget_stream method
+        async for status in self._aget_stream(f"{path}/{task_id}/stream", batch_response_type, timeout):
+            yield status
+
     async def _aget_stream(
         self,
         path: str,
         model: Type[T],
         timeout: float | None = None,
     ) -> AsyncGenerator[T, None]:
-        """Stream Server-Sent Events from an endpoint.
+        """Stream Server-Sent Events from an endpoint using httpx-sse.
 
         Args:
             path (str): API endpoint path relative to the project route prefix
@@ -147,24 +187,19 @@ class BaseResource:
 
         """
         start_time = time.time()
+        url = f"{self._client.project_route_prefix}/{path}"
 
-        async with self._client.async_session.stream(
-            "GET",
-            f"{self._client.project_route_prefix}/{path}",
-        ) as response:
-            response.raise_for_status()
+        async with aconnect_sse(self._client.async_session, "GET", url) as event_source:
+            event_source.response.raise_for_status()
 
-            async for data in response.aiter_text():
-                if not data.startswith("data:") or not data.endswith("\n\n"):
-                    raise RuntimeError(f"Malformed streaming data: {data}")
-
-                # Remove the starting "data:" element and any trailing newlines
-                data = data[5:]
-                data = data.rstrip("\n")
-
-                # Check timeout
+            async for sse in event_source.aiter_sse():
                 if timeout is not None and time.time() - start_time >= timeout:
                     raise TimeoutError("Stream operation timed out")
 
-                # Parse SSE data
-                yield model.model_validate_json(data)
+                if sse.data:
+                    try:
+                        parsed_data = model.model_validate_json(sse.data)
+                        yield parsed_data
+                    except ValueError as e:
+                        logger.warning(f"Failed to parse SSE data as JSON: {e}. Data: {sse.data[:200]}...")
+                        continue
